@@ -7,7 +7,7 @@ def register_sentry(client, worker):
                 exc_info=exc_info,
                 extra={
                     'job_id': job.id,
-                    'func': job.func,
+                    'func': job.func_name,
                     'args': job.args,
                     'kwargs': job.kwargs,
                     'description': job.description,
